<?php

namespace Litecms\Company\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litecms\Company\Forms\Year as YearForm;
use Litecms\Company\Http\Requests\YearResourceRequest;
use Litecms\Company\Http\Resources\YearResource;
use Litecms\Company\Http\Resources\YearsCollection;
use Litecms\Company\Models\Year;
use Litecms\Company\Actions\YearAction;
use Litecms\Company\Actions\YearActions;


/**
 * Resource controller class for year.
 */
class YearResourceController extends BaseController
{

    /**
     * Initialize year resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = YearForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('litecms.company.modules'), 'company', guard_url('company'));
            return $next($request);
        });
    }

    /**
     * Display a list of year.
     *
     * @return Response
     */
    public function index(YearResourceRequest $request)
    {
        $request = $request->all();
        $page = YearActions::run('paginate', $request);

        $data = new YearsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('company::year.names'))
            ->view('company::year.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display year.
     *
     * @param Request $request
     * @param Model   $year
     *
     * @return Response
     */
    public function show(YearResourceRequest $request, Year $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new YearResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('company::year.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('company::year.show')
            ->output();
    }

    /**
     * Show the form for creating a new year.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(YearResourceRequest $request, Year $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new YearResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('company::year.name'))
            ->view('company::year.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new year.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(YearResourceRequest $request, Year $model)
    {
        try {
            $request = $request->all();
            $model = YearAction::run('store', $model, $request);
            $data = new YearResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('company::year.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('company/year/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/company/year'))
                ->redirect();
        }

    }

    /**
     * Show year for editing.
     *
     * @param Request $request
     * @param Model   $year
     *
     * @return Response
     */
    public function edit(YearResourceRequest $request, Year $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new YearResource($model);
        // return view('company::year.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('company::year.name'))
            ->view('company::year.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the year.
     *
     * @param Request $request
     * @param Model   $year
     *
     * @return Response
     */
    public function update(YearResourceRequest $request, Year $model)
    {
        try {
            $request = $request->all();
            $model = YearAction::run('update', $model, $request);
            $data = new YearResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('company::year.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('company/year/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('company/year/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the year.
     *
     * @param Model   $year
     *
     * @return Response
     */
    public function destroy(YearResourceRequest $request, Year $model)
    {
        try {

            $request = $request->all();
            $model = YearAction::run('destroy', $model, $request);
            $data = new YearResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('company::year.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('company/year/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('company/year/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
